pub enum ScaleHint {
X(f64),
Y(f64),
Z(f64),
PorportionalX(f64),
PorportionalY(f64),
PorportionalZ(f64),
}Expand description
A hint for scaling the mobject.
Variants
X(f64)
Scale the mobject’s X axe
Y(f64)
Scale the mobject’s Y axe
Z(f64)
Scale the mobject’s Z axe
PorportionalX(f64)
Scale the mobject’s X axe, while other axes are scaled accordingly.
PorportionalY(f64)
Scale the mobject’s Y axe, while other axes are scaled accordingly.
PorportionalZ(f64)
Scale the mobject’s Z axe, while other axes are scaled accordingly.